/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package session;

import java.util.List;
import javax.ejb.LocalBean;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import tp3.CompteBancaire;

/**
 *
 * @author alix
 */
@Stateless
@LocalBean
public class GestionnaireDeCompteBancaire {
    @PersistenceContext
    private EntityManager em;
    
    // Creation d'un compte
    public void creerCompte(CompteBancaire c) {
        em.merge(c);
    }
    
    // Tout les comptes 
    public List<CompteBancaire> getAllComptes() {
        Query q = em.createQuery("select c from CompteBancaire c order by c.nom");
        
        return q.getResultList();
    }
    
    // Recherche de compte 
    public List<CompteBancaire> findComptes(String search) {
        Query q = em.createQuery("select c from CompteBancaire c where lower(c.nom) like :search");
        q.setParameter("search", "%" + search + "%");
        
        return q.getResultList();
    }
    
    // Pour la pagination
    public List<CompteBancaire> getComptes(int start, int limit) { 
        Query q = em.createNamedQuery("SELECT * FROM CompteBancaire");
        q.setFirstResult(start);
        q.setMaxResults(limit);
        
        return q.getResultList();
    }
    
    // Obtenir un compte en fonction de son id
    public CompteBancaire getCompte(int id) {
        Query q = em.createQuery("select c from CompteBancaire c where c.id=:id");
        q.setParameter("id", id);
        return (CompteBancaire) q.getSingleResult();
    }

    public void persist(Object object) {
        em.persist(object);
    }
    
    // MAJ d'un compte
    public CompteBancaire update(CompteBancaire c) {
        return em.merge(c);
    }
    
    // Suppression d'un compte
    public void delete(CompteBancaire c) {
        em.createQuery("delete from CompteBancaire c where c.id=" + c.getId()).executeUpdate();
    }
    
    // Comptes de test (OWGR)
    public void creerComptesTest() { 
        creerCompte(new CompteBancaire("Rory McIlroy", 150000));
        creerCompte(new CompteBancaire("Luke Donald", 150000));
        creerCompte(new CompteBancaire("Tiger Woods", 199150000));
        creerCompte(new CompteBancaire("Justin Rose", 150000));
        creerCompte(new CompteBancaire("Louis Oosthuizen", 150000));
        creerCompte(new CompteBancaire("Lee Westwood", 150000));
        creerCompte(new CompteBancaire("Adam Scott", 150000));
        creerCompte(new CompteBancaire("Jason Dufner", 150000));
        creerCompte(new CompteBancaire("Brandt Snedeker", 150000));
        creerCompte(new CompteBancaire("Webb Simpson", 150000));
        creerCompte(new CompteBancaire("Keegan Bradley", 150000));
        creerCompte(new CompteBancaire("Bubba Watson", 150000));
        creerCompte(new CompteBancaire("Ian Poulter", 150000));
        creerCompte(new CompteBancaire("Graeme McDowell", 150000));
        creerCompte(new CompteBancaire("Phil Mickelson", 150000));
        creerCompte(new CompteBancaire("Steve Stricker", 150000));
        creerCompte(new CompteBancaire("Nick Watney", 150000));
        creerCompte(new CompteBancaire("Peter Hanson", 150000));
        creerCompte(new CompteBancaire("Matt Kuchar", 150000));
        creerCompte(new CompteBancaire("Bo Van Pelt", 150000));
        creerCompte(new CompteBancaire("Dustin Johnson", 150000));
        creerCompte(new CompteBancaire("Sergio Garcia", 150000));
        creerCompte(new CompteBancaire("Ernie Els", 150000));
        creerCompte(new CompteBancaire("Zach Johnson", 150000));
        creerCompte(new CompteBancaire("Hunter Mahan", 150000));
        creerCompte(new CompteBancaire("Jim Furyk", 150000));
        creerCompte(new CompteBancaire("Charl Schwartzel", 150000));
        creerCompte(new CompteBancaire("Martin Kaymer", 150000));
        creerCompte(new CompteBancaire("Paul Lawrie", 150000));
        creerCompte(new CompteBancaire("Rickie Fowler", 150000));
        creerCompte(new CompteBancaire("Francesco Molinari", 150000));
        creerCompte(new CompteBancaire("Carl Pettersson", 150000));
        creerCompte(new CompteBancaire("Gonzalo Fdez-Castano", 150000));
        creerCompte(new CompteBancaire("Bill Haas", 150000));
        creerCompte(new CompteBancaire("Nicolas Colsaerts", 150000));
        creerCompte(new CompteBancaire("Branden Grace", 150000));
        creerCompte(new CompteBancaire("Jason Day", 150000));
        creerCompte(new CompteBancaire("John Senden", 150000));
        creerCompte(new CompteBancaire("Robert Garrigus", 150000));
        creerCompte(new CompteBancaire("David Toms", 150000));
        creerCompte(new CompteBancaire("Ryan Moore", 150000));
        creerCompte(new CompteBancaire("Scott Piercy", 150000));
        creerCompte(new CompteBancaire("Hiroyuki Fujita", 150000));
        creerCompte(new CompteBancaire("Thomas Bjorn", 150000));
        creerCompte(new CompteBancaire("Matteo Manassero", 150000));
        creerCompte(new CompteBancaire("David Lynn", 150000));
        creerCompte(new CompteBancaire("K.J. Choi", 150000));
        creerCompte(new CompteBancaire("Jamie Donaldson", 150000));
        creerCompte(new CompteBancaire("George Coetzee", 150000));
        creerCompte(new CompteBancaire("Thorbjorn Olesen", 150000));
        creerCompte(new CompteBancaire("Alexander Noren", 150000));
        creerCompte(new CompteBancaire("Miguel A Jimenez", 150000));
        creerCompte(new CompteBancaire("Richie Ramsay", 150000));
        creerCompte(new CompteBancaire("Rafael Cabrera Bello", 150000));
        creerCompte(new CompteBancaire("Fredrik Jacobson", 150000));
        creerCompte(new CompteBancaire("Shane Lowry", 150000));
        creerCompte(new CompteBancaire("Geoff Ogilvy", 150000));
        creerCompte(new CompteBancaire("Marcus Fraser", 150000));
        creerCompte(new CompteBancaire("Padraig Harrington", 150000));
        creerCompte(new CompteBancaire("Henrik Stenson", 150000));
        creerCompte(new CompteBancaire("Anders Hansen", 150000));
        creerCompte(new CompteBancaire("Marcel Siem", 150000));
        creerCompte(new CompteBancaire("Martin Laird", 150000));
        creerCompte(new CompteBancaire("Greg Chalmers", 150000));
        creerCompte(new CompteBancaire("Bae Sang-moon", 150000));
        creerCompte(new CompteBancaire("Bud Cauley", 150000));
        creerCompte(new CompteBancaire("Bernd Wiesberger", 150000));
        creerCompte(new CompteBancaire("Kevin Na", 150000));
        creerCompte(new CompteBancaire("Simon Dyson", 150000));
        creerCompte(new CompteBancaire("K.T. Kim", 150000));
        creerCompte(new CompteBancaire("John Huh", 150000));
        creerCompte(new CompteBancaire("Aaron Baddeley", 150000));
        creerCompte(new CompteBancaire("Thaworn Wiratchant", 150000));
        creerCompte(new CompteBancaire("Kyle Stanley", 150000));
        creerCompte(new CompteBancaire("Jonas Blixt", 150000));
        creerCompte(new CompteBancaire("Vijay Singh", 150000));
        creerCompte(new CompteBancaire("Ben Crane", 150000));
        creerCompte(new CompteBancaire("Toru Taniguchi", 150000));
        creerCompte(new CompteBancaire("Ryo Ishikawa", 150000));
        creerCompte(new CompteBancaire("Pablo Larrazabal", 150000));
        creerCompte(new CompteBancaire("Alvaro Quiros", 150000));
        creerCompte(new CompteBancaire("Ben Curtis", 150000));
        creerCompte(new CompteBancaire("Jonathan Byrd", 150000));
        creerCompte(new CompteBancaire("Brendon de Jonge", 150000));
        creerCompte(new CompteBancaire("Michael Thompson", 150000));
        creerCompte(new CompteBancaire("Mark Wilson", 150000));
        creerCompte(new CompteBancaire("Fredrik Andersson Hed", 150000));
        creerCompte(new CompteBancaire("Marc Leishman", 150000));
        creerCompte(new CompteBancaire("Noh Seung-yul", 150000));
        creerCompte(new CompteBancaire("Gaganjeet Bhullar", 150000));
        creerCompte(new CompteBancaire("Jeev Milkha Singh", 150000));
        creerCompte(new CompteBancaire("Stephen Gallacher", 150000));
        creerCompte(new CompteBancaire("Ross Fisher", 150000));
        creerCompte(new CompteBancaire("Y.E. Yang", 150000));
        creerCompte(new CompteBancaire("Danny Willett", 150000));
        creerCompte(new CompteBancaire("Jeff Overton", 150000));
        creerCompte(new CompteBancaire("Robert Rock", 150000));
        creerCompte(new CompteBancaire("Yuta Ikeda", 150000));
        creerCompte(new CompteBancaire("Koumei Oda", 150000));
        creerCompte(new CompteBancaire("Tim Clark", 150000));
    }
    
   public void transfer(CompteBancaire c1, CompteBancaire c2, double montant){
        c1.deposit(montant);
        c2.withdrawal(-montant);
        em.merge(c2);
        em.merge(c1);
    }
    
}
